#ifndef _NEWQPSKTX_H
#define _NEWQPSKTX_H

#include "complex.h"
#include "modemconfig.h"

/* --------------------------------------------------------------------- */

struct txstate {
	struct hdlc_transmitter hdlc;
	struct fecstate fec;
	unsigned bps, shreg;
	void (*txroutine) (void **);
	int statecntr, tuneonly, txdone;
	float *txwindowfunc;
	complex tunevect[TuneCarriers];
	complex datavect[DataCarriers];
	unsigned txword[SymbolBits];
	float txbuf[256];
	complex txwin[WindowLen];
	complex fftbuf[WindowLen];
};

/* --------------------------------------------------------------------- */

extern void init_newqpsktx(void **);
extern int newqpsktx(void **, int16_t *);

/* --------------------------------------------------------------------- */

#endif
